StringColumnRef

Enum StringColumnRef 

pub enum StringColumnRef<'a> {
    DictionaryInt8(&'a DictionaryArray<Int8Type>, &'a StringArray),
    DictionaryInt32(&'a DictionaryArray<Int32Type>, &'a StringArray),
    Utf8(&'a StringArray),
    Utf8View(&'a StringViewArray),
}
Reference to a string column in a supported Arrow string representation.

Variants



DictionaryInt8(&'a DictionaryArray<Int8Type>, &'a StringArray)



DictionaryInt32(&'a DictionaryArray<Int32Type>, &'a StringArray)



Utf8(&'a StringArray)



Utf8View(&'a StringViewArray)

Implementations

Source

impl StringColumnRef<'_>

pub fn len(&self) -> usize

Returns the number of rows.

pub fn is_empty(&self) -> bool

Returns whether the column contains no rows.

pub fn try_from_array(array: &dyn Array) -> Option<StringColumnRef<'_>>

Returns a string view when array uses Utf8 or Utf8View encoding.

pub fn value(&self, i: usize) -> &str

Returns the string value at row i.

Panics

Panics if i is out of bounds or a dictionary column contains an invalid key.

pub fn is_null(&self, i: usize) -> bool

Returns whether the value at row i is null.

pub fn value_opt(&self, i: usize) -> Option<&str>

Returns the string value at row i, or None when it is null.