money_array

Function money_array 

pub fn money_array(
    values: impl IntoIterator<Item = Option<Money>>,
) -> Result<StructArray, ArrowError>
Builds a nullable struct array containing monetary amounts and currencies.

Errors

Returns an [ArrowError] if an amount or dictionary value cannot be represented.