record_batch_with_identifier_column

Function record_batch_with_identifier_column 

pub fn record_batch_with_identifier_column(
    batch: RecordBatch,
    identifier: Option<&str>,
) -> Result<RecordBatch, ArrowError>
Adds the catalog identifier column used by table-oriented catalog storage.

The column is nullable so custom data without a DataType.identifier() can still be stored in the same type table.

Errors

Returns an [ArrowError] if the record batch cannot be rebuilt.