pub fn schema_with_identifier_column(schema: &Schema) -> SchemaExpand description
Builds a schema with the catalog identifier column appended if absent.
pub fn schema_with_identifier_column(schema: &Schema) -> SchemaBuilds a schema with the catalog identifier column appended if absent.