pub fn record_batch_with_identifier_values(
batch: RecordBatch,
identifier_values: Vec<Option<String>>,
) -> Result<RecordBatch, ArrowError>Expand description
Adds the catalog identifier column with one identifier value per row.
Errors
Returns an [ArrowError] if the number of identifier values differs from
the record batch row count or the record batch cannot be rebuilt.